@@ -443,6 +443,12 @@ atspi_state_type_get_type (void)
 			{ ATSPI_STATE_VISITED,
 			  "ATSPI_STATE_VISITED",
 			  "visited" },
+			{ ATSPI_STATE_CHECKABLE,
+			  "ATSPI_STATE_CHECKABLE",
+			  "checkable" },
+			{ ATSPI_STATE_HAS_POPUP,
+			  "ATSPI_STATE_HAS_POPUP",
+			  "has-popup" },
 			{ ATSPI_STATE_LAST_DEFINED,
 			  "ATSPI_STATE_LAST_DEFINED",
 			  "last-defined" },
@@ -977,6 +983,45 @@ atspi_role_get_type (void)
 			{ ATSPI_ROLE_LEVEL_BAR,
 			  "ATSPI_ROLE_LEVEL_BAR",
 			  "level-bar" },
+			{ ATSPI_ROLE_TITLE_BAR,
+			  "ATSPI_ROLE_TITLE_BAR",
+			  "title-bar" },
+			{ ATSPI_ROLE_BLOCK_QUOTE,
+			  "ATSPI_ROLE_BLOCK_QUOTE",
+			  "block-quote" },
+			{ ATSPI_ROLE_AUDIO,
+			  "ATSPI_ROLE_AUDIO",
+			  "audio" },
+			{ ATSPI_ROLE_VIDEO,
+			  "ATSPI_ROLE_VIDEO",
+			  "video" },
+			{ ATSPI_ROLE_DEFINITION,
+			  "ATSPI_ROLE_DEFINITION",
+			  "definition" },
+			{ ATSPI_ROLE_ARTICLE,
+			  "ATSPI_ROLE_ARTICLE",
+			  "article" },
+			{ ATSPI_ROLE_LANDMARK,
+			  "ATSPI_ROLE_LANDMARK",
+			  "landmark" },
+			{ ATSPI_ROLE_LOG,
+			  "ATSPI_ROLE_LOG",
+			  "log" },
+			{ ATSPI_ROLE_MARQUEE,
+			  "ATSPI_ROLE_MARQUEE",
+			  "marquee" },
+			{ ATSPI_ROLE_MATH,
+			  "ATSPI_ROLE_MATH",
+			  "math" },
+			{ ATSPI_ROLE_RATING,
+			  "ATSPI_ROLE_RATING",
+			  "rating" },
+			{ ATSPI_ROLE_TIMER,
+			  "ATSPI_ROLE_TIMER",
+			  "timer" },
+			{ ATSPI_ROLE_STATIC,
+			  "ATSPI_ROLE_STATIC",
+			  "static" },
 			{ ATSPI_ROLE_LAST_DEFINED,
 			  "ATSPI_ROLE_LAST_DEFINED",
 			  "last-defined" },
